==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v27ter_tx_2400_fixed_rrc.h <==
#define PULSESHAPER_2400_GAIN        0.875533f
#define PULSESHAPER_2400_COEFF_SETS  20
static const int16_t pulseshaper_2400[PULSESHAPER_2400_COEFF_SETS][9] =
{
    {
             144,     /* Filter 0 */
             308,
            -432,
           -2162,
           16681,
           16681,
           -2162,
            -432,
             308
    },
    {
             105,     /* Filter 1 */
             379,
            -311,
           -2761,
           19232,
           14102,
           -1560,
            -516,
             228
    },
    {
              58,     /* Filter 2 */
             434,
            -155,
           -3327,
           21702,
           11548,
            -978,
            -560,
             141
    },
    {
               4,     /* Filter 3 */
             470,
              28,
           -3830,
           24037,
            9071,
            -439,
            -566,
              52
    },
    {
             -52,     /* Filter 4 */
             484,
             232,
           -4238,
           26183,
            6715,
              39,
            -536,
             -32
    },
    {
            -110,     /* Filter 5 */
             474,
             445,
           -4521,
           28093,
            4521,
             445,
            -474,
            -110
    },
    {
            -164,     /* Filter 6 */
             439,
             657,
           -4647,
           29721,
            2524,
             770,
            -386,
            -176
    },
    {
            -213,     /* Filter 7 */
             381,
             854,
           -4586,
           31029,
             752,
            1008,
            -279,
            -229
    },
    {
            -252,     /* Filter 8 */
             300,
            1023,
           -4315,
           31986,
            -776,
            1160,
            -159,
            -267
    },
    {
            -278,     /* Filter 9 */
             201,
            1150,
           -3811,
           32570,
           -2047,
            1229,
             -35,
            -287
    },
    {
            -291,     /* Filter 10 */
              87,
            1223,
           -3058,
           32767,
           -3058,
            1223,
              87,
            -291
    },
    {
            -287,     /* Filter 11 */
             -35,
            1229,
           -2047,
           32570,
           -3811,
            1150,
             201,
            -278
    },
    {
            -267,     /* Filter 12 */
            -159,
            1160,
            -776,
           31986,
           -4315,
            1023,
             300,
            -252
    },
    {
            -229,     /* Filter 13 */
            -279,
            1008,
             752,
           31029,
           -4586,
             854,
             381,
            -213
    },
    {
            -176,     /* Filter 14 */
            -386,
             770,
            2524,
           29721,
           -4647,
             657,
             439,
            -164
    },
    {
            -110,     /* Filter 15 */
            -474,
             445,
            4521,
           28093,
           -4521,
             445,
             474,
            -110
    },
    {
             -32,     /* Filter 16 */
            -536,
              39,
            6715,
           26183,
           -4238,
             232,
             484,
             -52
    },
    {
              52,     /* Filter 17 */
            -566,
            -439,
            9071,
           24037,
           -3830,
              28,
             470,
               4
    },
    {
             141,     /* Filter 18 */
            -560,
            -978,
           11548,
           21702,
           -3327,
            -155,
             434,
              58
    },
    {
             228,     /* Filter 19 */
            -516,
           -1560,
           14102,
           19232,
           -2761,
            -311,
             379,
             105
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v27ter_tx_2400_fixed_rrc.h <==
#define TX_PULSESHAPER_2400_GAIN        0.875533f
#define TX_PULSESHAPER_2400_COEFF_SETS  20
static const int16_t tx_pulseshaper_2400[TX_PULSESHAPER_2400_COEFF_SETS][9] =
{
    {
             144,     /* Filter 0 */
             308,
            -432,
           -2162,
           16681,
           16681,
           -2162,
            -432,
             308
    },
    {
             105,     /* Filter 1 */
             379,
            -311,
           -2761,
           19232,
           14102,
           -1560,
            -516,
             228
    },
    {
              58,     /* Filter 2 */
             434,
            -155,
           -3327,
           21702,
           11548,
            -978,
            -560,
             141
    },
    {
               4,     /* Filter 3 */
             470,
              28,
           -3830,
           24037,
            9071,
            -439,
            -566,
              52
    },
    {
             -52,     /* Filter 4 */
             484,
             232,
           -4238,
           26183,
            6715,
              39,
            -536,
             -32
    },
    {
            -110,     /* Filter 5 */
             474,
             445,
           -4521,
           28093,
            4521,
             445,
            -474,
            -110
    },
    {
            -164,     /* Filter 6 */
             439,
             657,
           -4647,
           29721,
            2524,
             770,
            -386,
            -176
    },
    {
            -213,     /* Filter 7 */
             381,
             854,
           -4586,
           31029,
             752,
            1008,
            -279,
            -229
    },
    {
            -252,     /* Filter 8 */
             300,
            1023,
           -4315,
           31986,
            -776,
            1160,
            -159,
            -267
    },
    {
            -278,     /* Filter 9 */
             201,
            1150,
           -3811,
           32570,
           -2047,
            1229,
             -35,
            -287
    },
    {
            -291,     /* Filter 10 */
              87,
            1223,
           -3058,
           32767,
           -3058,
            1223,
              87,
            -291
    },
    {
            -287,     /* Filter 11 */
             -35,
            1229,
           -2047,
           32570,
           -3811,
            1150,
             201,
            -278
    },
    {
            -267,     /* Filter 12 */
            -159,
            1160,
            -776,
           31986,
           -4315,
            1023,
             300,
            -252
    },
    {
            -229,     /* Filter 13 */
            -279,
            1008,
             752,
           31029,
           -4586,
             854,
             381,
            -213
    },
    {
            -176,     /* Filter 14 */
            -386,
             770,
            2524,
           29721,
           -4647,
             657,
             439,
            -164
    },
    {
            -110,     /* Filter 15 */
            -474,
             445,
            4521,
           28093,
           -4521,
             445,
             474,
            -110
    },
    {
             -32,     /* Filter 16 */
            -536,
              39,
            6715,
           26183,
           -4238,
             232,
             484,
             -52
    },
    {
              52,     /* Filter 17 */
            -566,
            -439,
            9071,
           24037,
           -3830,
              28,
             470,
               4
    },
    {
             141,     /* Filter 18 */
            -560,
            -978,
           11548,
           21702,
           -3327,
            -155,
             434,
              58
    },
    {
             228,     /* Filter 19 */
            -516,
           -1560,
           14102,
           19232,
           -2761,
            -311,
             379,
             105
    }
};
